@@ -3,7 +3,7 @@ package BioX::Workflow::Command::run::Utils::Files::TrackChanges;
 use MooseX::App::Role;
 use namespace::autoclean;
 
-use Data::Walk;
+use Data::Walk 2.01;
 use File::Details;
 use File::stat;
 use Time::localtime;
@@ -12,9 +12,8 @@ use DateTime::Format::Strptime;
 
 =head3 files
 
-Files just for this rule
+Container for list of files just for this rule
 
-##TODO Make this a hash?
 =cut
 
 has 'files' => (
@@ -39,12 +38,12 @@ sub walk_FILES {
     $self->pre_FILES( $attr, 'INPUT' );
     $self->add_graph('INPUT');
     $self->clear_files;
-    $self->files([]);
+    $self->files( [] );
 
     $self->pre_FILES( $attr, 'OUTPUT' );
     $self->add_graph('OUTPUT');
     $self->clear_files;
-    $self->files([]);
+    $self->files( [] );
 }
 
 sub pre_FILES {
@@ -56,6 +55,7 @@ sub pre_FILES {
         wanted => sub { $self->walk_INPUT(@_) }
       },
       $attr->$cond;
+
     $self->uniq_files;
     $self->sort_files;
 }
@@ -78,7 +78,7 @@ sub walk_INPUT {
 
     my $file = $ref->absolute;
     $file = "$file";
-    $self->push_files( $file );
+    $self->push_files($file);
 }
 
 1;
